---
title: Weaving a robust microservice mesh with Istio
overview: Istio 0.1 announcement
published: true
permalink: blog/0.1-announcement.html
attribution: The Istio Team
layout: post
type: markdown
---

THIS IS STILL A WORK IN PROGRESS

We are happy to announce the 0.1 release of Istio: an open platform that provides a uniform way to connect, manage, and
secure microservices. Istio gives operators visibility into, and runtime control over the traffic between microservices without requiring changes to application code. Istio operators can transparently enable reliable service identity and traffic encryption to lock down their microservice mesh. We are providing this functionality for the Kubernetes environment in this release and will add support for other environments like virtual machines, and Cloud Foundry in the coming months.

<!--end_excerpt-->

Istio’s creation was motivated by the emergence of microservices as a modern way to build scalable applications. As monolithic applications are decomposed into a distributed system of microservices that scale dynamically, problems such as service discovery, load balancing, and failure recovery become increasingly important to solve uniformly. As the application gains more agility, updates are made to different parts of the application at different times. Developers need the ability to experiment with different features in production, or deploy canary releases, without impacting the system as a whole. Operators need to enforce organization-wide policies, such as rate limits, ACLs, etc., without requiring updates to each microservice.

Today these capabilities must be cobbled together by developers and operators from a large set of point-solutions. Consistent behaviors across language, runtime and environment become extremely hard to attain. Makeshift solutions to security issues can easily open the door for widespread exploits.

Istio is designed to turn a set of disparate microservices into an integrated service mesh. It does so by systematically injecting a sidecar proxy into the network paths between services. Sophisticated traffic management controls can now be applied such as load-balancing and fine-grained routing. The sidecar approach enables Istio to extract a wealth of signals about traffic behavior, which it uses to enforce policy decisions such as fine-grained access control and rate limits that are configured by operators. Those same signals are also sent to monitoring systems to provide visibility over the entire mesh. Also, since Istio proxies are enabled with emerging open security standards like [SPIFFE](https://github.com/spiffe), operators can rest assured that inter-service traffic can be authenticated and secured at the transport layer. 

One of the big benefits of Istio’s sidecar proxy approach is that you can overlay Istio on an existing deployment and instantaneously enable all these capabilities with no need to re-architect. Once in place, Istio can be extended to integrate with alternate policy management and operational insight tools to better fit within your production ecosystem. 

Istio uses an extended version of [Envoy](https://lyft.github.io/envoy) as its sidecar proxy.  Envoy was open sourced by Lyft who have been successfully using it in production for over a year to manage 100+ services spanning 10,000+ VMs processing 2M requests/second at peak load.

Here’s a list of some of the capabilities Istio provides out of the box:

- Automatic encryption of service-to-service communication with strong identity assertions between services leveraging mutual TLS and SPIFFE specification.

- Intelligent per-request load balancing for HTTP/1.1, HTTP/2 & [gRPC](http://grpc.io) in addition to connection-based load balancing for TCP.

- Precise control over traffic routing with expressive rules. Retry budgets, circuit breakers and fault injection to improve and test resiliency.

- A policy engine supporting ACLs, rate limits and quotas that can be extended to integrate with internal policy systems.

- Automatic extraction of standardized metrics, logs, and traces for all traffic within the service mesh. Integrations with Prometheus and Zipkin are provided by default and others can be added easily.

Istio is being developed completely in the open by Google, IBM and Lyft. To get involved, connect with us via any of these channels:
 
- [istio-users@](https://groups.google.com/forum/#!forum/istio-users) mailing list

- Stack Overflow for questions

- [GitHub](https://github.com/istio/istio) for filing issues
 
- And follow @istio on Twitter or join [istio-announce@](https://groups.google.com/forum/#!forum/istio-announce) for key announcements regarding 
the project.
 
From everyone working on Istio, welcome aboard!
